
export const CONFIG_FILES = {
    gdeployTemplate: '/usr/share/cockpit/ovirt-dashboard/gdeploy-templates/ovirt-gluster-hc.conf',
    heCommonAnsFile: '/usr/share/cockpit/ovirt-dashboard/gdeploy-templates/he-common.conf',
    gdeployConfigFile: '/var/lib/ovirt-hosted-engine-setup/gdeploy/gdeployConfig.conf',
    heAnsfileFile: '/var/lib/ovirt-hosted-engine-setup/answers/he-answer.conf',
    expandClusterConfigFile: '/var/lib/ovirt-hosted-engine-setup/gdeploy/expandClusterConfig.conf'
}
